def something():
    print("something")

def something_else():
    print("something else")

def something_else_else():
    print("something else else")

def something_else_else_else():
    print("something else else else")

def something_else_else_else_else():
    print("something else else else else")

def something_else_else_else_else_else():
    print("something else else else else else")


def something_else_else_else_else_else_else():
    print("something else else else else else else")

